@@ -2,17 +2,18 @@ use clap::{
     app_from_crate, crate_authors, crate_description, crate_name, crate_version, AppSettings,
     SubCommand,
 };
+use itertools::Itertools;
 
 fn next_workspace_number(conn: &mut swayipc::Connection) -> Result<i32, swayipc::Error> {
     let workspaces = conn.get_workspaces()?;
     let mut ids: Vec<i32> = workspaces.iter().map(|w| w.num).collect();
     ids.sort_unstable();
-    for i in 1..ids.len() + 1 {
-        if ids[i - 1] != i as i32 {
-            return Ok(i as i32);
-        }
-    }
-    Ok((ids.len() + 1) as i32)
+    let len = ids.len() as i32;
+    Ok(ids
+        .into_iter()
+        .tuple_windows()
+        .find(|(cur, next)| cur + 1 != *next)
+        .map_or(len + 1, |(cur, _)| cur + 1))
 }
 
 fn main() -> Result<(), swayipc::Error> {
@@ -25,12 +26,12 @@ fn main() -> Result<(), swayipc::Error> {
         .setting(AppSettings::SubcommandRequired)
         .get_matches();
     let mut conn = swayipc::Connection::new()?;
-    match params.subcommand_name() {
-        Some("open") => {
+    match params.subcommand_name().expect("unexpected subcommand") {
+        "open" => {
             let next_id = next_workspace_number(&mut conn)?;
             conn.run_command(format!("workspace {}", next_id))?;
         }
-        Some("move") => {
+        "move" => {
             let next_id = next_workspace_number(&mut conn)?;
             conn.run_command(format!("move container to workspace {}", next_id))?;
             conn.run_command(format!("workspace {}", next_id))?;
